package org.dive4elements.river.model;

import com.vividsolutions.jts.geom.Point;

import org.dive4elements.river.backend.SessionHolder;

import java.io.Serializable;

import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToOne;
import javax.persistence.Table;

import org.hibernate.Query;
import org.hibernate.Session;

import org.hibernate.annotations.Type;


@Entity
@Table(name = "gauge_location")
public class GaugeLocation
implements   Serializable
{
    private Integer    id;
    private River      river;
    private String     name;
    private Point      geom;


    public GaugeLocation() {
    }


    @Id
    @Column(name = "id")
    public Integer getId() {
        return id;
    }


    public void setId(Integer id) {
        this.id = id;
    }


    @OneToOne
    @JoinColumn(name = "river_id")
    public River getRiver() {
        return river;
    }


    public void setRiver(River river) {
        this.river = river;
    }


    @Column(name = "name")
    public String getName() {
        return name;
    }


    public void setName(String name) {
        this.name = name;
    }


    @Column(name = "geom")
    @Type(type = "org.hibernatespatial.GeometryUserType")
    public Point getGeom() {
        return geom;
    }


    public void setGeom(Point geom) {
        this.geom = geom;
    }


    /**
     * Returns a list of RiverAxisKm objects for a given river.
     *
     * @param riverid The ID of a river in the database.
     *
     * @return a list of RiverAxisKm objects.
     */
    public static List<GaugeLocation> getGaugeLocations(int riverid, String name) {
        Session session = SessionHolder.HOLDER.get();

        Query query = session.createQuery(
            "from GaugeLocation where river.id =:riverid and name=:name");
        query.setParameter("riverid", riverid);
        query.setParameter("name", name);

        List<GaugeLocation> list = query.list();

        return list;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
